Module parse_trace

Module parse_trace 

Structs

MacroExpansion
A single macro expansion pair: the “expanding” text and the “to” text.
TraceGroup
A group of macro expansions from a single note: trace_macro block.
TraceParser
Iterator over trace groups parsed from macro tracing output.

Enums

MacroExpansionKind
The kind of macro invocation.

Functions

parse_trace
Parse macro tracing output from a reader.