pub struct TraceGroup {
pub expansions: Vec<MacroExpansion>,
}Expand description
A group of macro expansions from a single note: trace_macro block.
Fields
expansions: Vec<MacroExpansion>Trait Implementations
Sourceimpl Clone for TraceGroup
impl Clone for TraceGroup
Sourcefn clone(&self) -> TraceGroup
fn clone(&self) -> TraceGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceGroup
impl Debug for TraceGroup
Sourceimpl PartialEq for TraceGroup
impl PartialEq for TraceGroup
Sourcefn eq(&self, other: &TraceGroup) -> bool
fn eq(&self, other: &TraceGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for TraceGroup
impl StructuralPartialEq for TraceGroup